@@ -62,6 +62,10 @@ class PlaylistManager(val service: PlaybackService) : MediaWrapperList.EventList
 
     fun isValidPosition(position: Int) = position in 0 until mediaList.size()
 
+    init {
+        if (settings.getBoolean("audio_save_repeat", false)) repeating = settings.getInt(AUDIO_REPEAT_MODE_KEY, Constants.REPEAT_NONE)
+    }
+
     /**
      * Loads a selection of files (a non-user-supplied collection of media)
      * into the primary or "currently playing" playlist.
@@ -357,7 +361,7 @@ class PlaylistManager(val service: PlaybackService) : MediaWrapperList.EventList
         if (media.type == MediaWrapper.TYPE_VIDEO || canSwitchToVideo || media.isPodcast) {
             //Save progress
             val time = player.getTime()
-            val length = player.getLength()
+            val length = player.length
             var progress = time / length.toFloat()
             if (progress > 0.95f || length - time < 10000) {
                 //increase seen counter if more than 95% of the media have been seen
@@ -526,10 +530,10 @@ class PlaylistManager(val service: PlaybackService) : MediaWrapperList.EventList
     private fun seekToResume(media: MediaWrapper) {
         var mw = media
         if (savedTime > 0L) {
-            if (savedTime < 0.95 * player.getLength()) player.seek(savedTime)
+            if (savedTime < 0.95 * player.length) player.seek(savedTime)
             savedTime = 0L
         } else {
-            val length = player.getLength()
+            val length = player.length
             if (mw.length <= 0L && length > 0L) {
                 mw = medialibrary.findMedia(mw)
                 if (mw.id != 0L) {
